Django Frontend Skeleton documentation — django-frontend-skeleton 0.5.0 documentation

### Navigation

- index
- next |
- django-frontend-skeleton 0.5.0 documentation »

# Django Frontend Skeleton documentation

Django Frontend Skeleton is a basic Django template skeleton built on HTML5 Boilerplate and Twitter Bootstrap.

With the convenience of an installable Django application, create custom templates built on top of one of the most well-known, widespread templates (HTML5 Boilerplate) and a robust front-end framework (Twitter Bootstrap.)

## Starring

- HTML5 Boilerplate (based on 4.1.0)
- Modernizr (2.6.2)
- jQuery (1.9.1)
- Twitter Bootstrap (2.3.0)
- iOS-Orientationchange-Fix

## Contents

- Getting Started
  - Install
  - Extend
- Template tags
  - HTML5 Boilerplate
  - Twitter Bootstrap
- Template blocks
  - html
  - meta
  - head_css
  - head_js
  - body_id
  - body_class
  - body_content
  - body_js
- License
  - Component Specific Licenses
- Changelog
  - 0.5.0
  - 0.4.0
  - 0.3.0
  - 0.2.0
  - 0.1.0

### Navigation

- index
- next |
- django-frontend-skeleton 0.5.0 documentation »